KeyCode

Enum KeyCode 

pub enum KeyCode {
Show 88 variants Char(char), Hyper, Super, Meta, Cancel, Backspace, Tab, Clear, Enter, Shift, Escape, LeftShift, RightShift, Control, LeftControl, RightControl, Alt, LeftAlt, RightAlt, Menu, LeftMenu, RightMenu, Pause, CapsLock, PageUp, PageDown, End, Home, LeftArrow, RightArrow, UpArrow, DownArrow, Select, Print, Execute, PrintScreen, Insert, Delete, Help, LeftWindows, RightWindows, Applications, Sleep, Numpad0, Numpad1, Numpad2, Numpad3, Numpad4, Numpad5, Numpad6, Numpad7, Numpad8, Numpad9, Multiply, Add, Separator, Subtract, Decimal, Divide, Function(u8), NumLock, ScrollLock, Copy, Cut, Paste, BrowserBack, BrowserForward, BrowserRefresh, BrowserStop, BrowserSearch, BrowserFavorites, BrowserHome, VolumeMute, VolumeDown, VolumeUp, MediaNextTrack, MediaPrevTrack, MediaStop, MediaPlayPause, ApplicationLeftArrow, ApplicationRightArrow, ApplicationUpArrow, ApplicationDownArrow, KeyPadHome, KeyPadEnd, KeyPadPageUp, KeyPadPageDown, KeyPadBegin, // some variants omitted
}
Which key is pressed. Not all of these are probable to appear on most systems. A lot of this list is @wez trawling docs and making an entry for things that might be possible in this first pass.

Variants



Char(char)

The decoded unicode character



Hyper



Super



Meta



Cancel

Ctrl-break on windows



Backspace



Tab



Clear



Enter



Shift



Escape



LeftShift



RightShift



Control



LeftControl



RightControl



Alt



LeftAlt



RightAlt



Menu



LeftMenu



RightMenu



Pause



CapsLock



PageUp



PageDown



End



Home



LeftArrow



RightArrow



UpArrow



DownArrow



Select



Print



Execute



PrintScreen



Insert



Delete



Help



LeftWindows



RightWindows



Applications



Sleep



Numpad0



Numpad1



Numpad2



Numpad3



Numpad4



Numpad5



Numpad6



Numpad7



Numpad8



Numpad9



Multiply



Add



Separator



Subtract



Decimal



Divide



Function(u8)

F1-F24 are possible



NumLock



ScrollLock



Copy



Cut



Paste



BrowserBack



BrowserForward



BrowserRefresh



BrowserStop



BrowserSearch



BrowserFavorites



BrowserHome



VolumeMute



VolumeDown



VolumeUp



MediaNextTrack



MediaPrevTrack



MediaStop



MediaPlayPause



ApplicationLeftArrow



ApplicationRightArrow



ApplicationUpArrow



ApplicationDownArrow



KeyPadHome



KeyPadEnd



KeyPadPageUp



KeyPadPageDown



KeyPadBegin

Implementations

Source

impl KeyCode

pub fn normalize_shift_to_upper_case(self, modifiers: Modifiers) -> KeyCode

if SHIFT is held and we have KeyCode::Char(‘c’) we want to normalize that keycode to KeyCode::Char(‘C’); that is what this function does. In theory we should give the same treatment to keys like [ -> { but that assumes something about the keyboard layout and is probably better done in the gui frontend rather than this layer. In fact, this function might be better off if it lived elsewhere.

pub fn is_modifier(self) -> bool

Return true if the key represents a modifier key.

pub fn encode( &self, mods: Modifiers, modes: KeyCodeEncodeModes, is_down: bool, ) -> Result<String, Error>

Returns the byte sequence that represents this KeyCode and Modifier combination,